VarSet
======

.. currentmodule:: pqp.symbols

.. autoclass:: VarSet
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~VarSet.to_latex

   .. rubric:: Methods Documentation

   .. automethod:: to_latex
